@@ -30,7 +30,7 @@
 //!
 
 use futures::stream::TryStreamExt;
-use mongodb::{bson::doc, error::Result, options::FindOptions};
+use mongodb::{bson::{doc, Document}, error::Result, options::FindOptions};
 use serde::de::DeserializeOwned;
 
 use crate::Collection;
@@ -41,13 +41,14 @@ impl<T: DeserializeOwned + Unpin + Send + Sync> Collection<T> {
         num_items: i64,
         skip: i64,
         offset: u64,
+        filter: impl Into<Option<Document>>
     ) -> Result<Vec<T>> {
         let find_options = FindOptions::builder()
             .sort(doc! { "_id": -1 })
             .skip(offset)
             .limit(num_items * skip)
             .build();
-        let mut cursor = self.collection.find(None, find_options).await?;
+        let mut cursor = self.collection.find(filter, find_options).await?;
         let mut items = Vec::new();
         let mut step = 0;
         while let Some(item) = cursor.try_next().await? {
